@@ -14,44 +14,82 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
+from nonebot import require
+require('nonebot_plugin_apscheduler')
+require('nonebot_plugin_htmlrender')
+require('nonebot_plugin_txt2img')
+from .l4d2_web import web,webUI
+
 from typing import Tuple,Union,List
 from time import sleep
 
 from nonebot.matcher import Matcher
 from nonebot.typing import T_State
-from nonebot.params import CommandArg,ArgPlainText,RegexGroup,Arg,RawCommand,CommandStart
+from nonebot.params import CommandArg,ArgPlainText,RegexGroup,Arg
 from nonebot import get_driver, require
-from nonebot.plugin import PluginMetadata
+from typing import Annotated
+from nonebot.params import Keyword
 
-
-from .config import *
-from .utils import *
-from .command import *
+from .l4d2_utils.config import *
+from .l4d2_utils.utils import *
+from .l4d2_utils.command import *
 from .l4d2_image.steam import url_to_byte,url_to_byte_name
 
 from .l4d2_data import sq_L4D2
-
+from .l4d2_push import *
 from .l4d2_image.vtfs import img_to_vtf
-from .l4d2_queries.ohter import load_josn
-from .l4d2_queries.qqgroup import write_json
 from .l4d2_file import updown_l4d2_vpk,all_zip_to_one
-
-from .txt_to_img import mode_txt_to_img
-# from .l4d2_server import RCONClient
+from .l4d2_file.input_json import *
+from .l4d2_utils.txt_to_img import mode_txt_to_img
 scheduler = require("nonebot_plugin_apscheduler").scheduler
-if l4_web:
-    from .l4d2_web import web,webUI
-else:
-    pass
+from nonebot.plugin import PluginMetadata
 
 driver = get_driver()
+logo ="""
+    ......                  ` .]]@@@@@@@@@@@@@@@@@@@@@@@@@@@@@OO^       
+    ......                ,/@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@OO^       
+    ......            /O@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@OO^       
+    `.....           ,@^=.OOO\/\@@@@@@@@@@@@@@@@@@@@OO//@@@@@/OO\]]]OO\]
+    ``....          ,@@/=^OOOOOOOO@@@@@@@@@@@\]OOOOOOO^^=@@@@OOOOOOOOOOO
+    `.....          O@O^==OOOOOOOO@@@/.,@@@OOOOOOOOOOO\O,@@@@OOOOOOOOO@@
+    ......    ,    .@@@^=`OOOOOOOOO/  ,O@@OOOOOOOOOOOOOO.O@@@OO/[[[[[[[.
+    ......    =..,//@@@^=`OOOOOOOOO@.*=@@@OOOOOOOOOOOOOO]@@@OOO.     ,/`
+    ......    =.\O]`,@O^\=OOOO@@@@@@O`=@@@@@@@OOOOOOOO*O,OO^....[[``]./]
+    ......    ,^.oOoO@O^=,OO@@@@@OoO`\O\OO@@@@OOOOOOOOO]@@^.]]]/OOOo.,OO
+    ......     =.=OOOO@@@@/[[=/.^,/....*.=^,[O@@@@OOOO.@@OOOOOOOOO/..OOO
+    ......      \.\OO`.,....*`.=.^.......=....=@O[\@@O@@[^ ,`.=Oo*.,OOO/
+    ......       ,@,`...  ....=^/......../....=/O^....\..O]/[\O[*]/OOO. 
+    ......       ]@^.,....*..=O\^........^..*.O.\O.^..=^\..,\/\@OOO[.   
+    ......    ,,`O^.,..../.,O`//........=..=`=^.=O`O..=^..OOO*/OOO.     
+    ......   .=.=@..^...=^/O`*OO.]...o**\.,/=^...O^@^..^...OO^=`OOO`    
+    ......  `=.,O^./.*.,OO`,.,/@/.*,O`,O*/@/`....\O\^......Oo^.^,OOO.   
+    ...... .,`.o=^=^.../`...]/`***/O^/@oO@`..[[[[\/=\......O^^...=OO^   
+    ......  ^.=`O^O.*.=\],]]]/\O/\@O[=O/`        =.=O....=^O^*....OOO.  
+    ...... =../=OO^.*.=@@[[,@@@\ .. ..    ,\@@@@@] =O...`=^@`.....=OO^  
+    ...... `..^=OO^.^,@`  ^ =oO\          .O\O@\.,\@@..,^OoO......=OOO. 
+    ...... ^...=OO^.^.@^ =^*=^,O          \..Ooo^  ,@..=OOOO..*....OOO. 
+    ...... ^...=o@^.`.O@. .  ... .. ....  ^.*`.*^  =^..o@oO@*.=....OOO^ 
+    ...... ^...=oOO.*.\O   ... .......... .\   ` ,=^*.,OOOO@^.=`^..=OO\ 
+    ...... ^...*`OO.*.=O ........          ......,`*^.=OOOo@^.=^^..=OOO.
+    ...... \....*oO^..*O^ ....... @OO[[[`  ......../.,@OOOo@^..OO...OOO`
+    ...... =.....*.=`..,O`       .O.....=   ... ^.=..OOOOO=O@..=O^..OOO^
+    ...... .^...**.O@...\O^ .     \.....`   .^ /.,^.=O@OO`=O@^..OO`.=OO\
+    ...... .^...,.=O=@...OO@\      ,[O\=.    ./`.*.*OOOOO..OOO*..OO.,OOO
+    ....../O....../^=O@`..O@@@@@]`    .* .,/@@/..../OOOOO*.,OOO..,OO`=OO
+    @OO\ooO....,*/@^,@@@\..@^[\@@@@@@O]*]//[`@^*^*=OOOOOO^..=OO\...\^.\@
+    OOooo^..`./oOO@/ =^\/^.^\\....=]......,/@@^O^*O.... .,][],OO\....\`.
+    @Oooo\/]OOOOOO/  .  \.=^....,..........[.,OO^=^.    /    ,`\OO`.....
+    """
 
 
-__version__ = "0.4.6"
+__version__ = "0.5.7"
 __plugin_meta__ = PluginMetadata(
     name="求生之路小助手",
     description='群内对有关求生之路的查询和操作',
-    usage='求生服务器操作指令',
+    usage=logo,
+    type="application",
+    homepage="https://github.com/Agnes4m/nonebot_plugin_l4d2_server",
+    supported_adapters={"~onebot.v11"},
     extra={
         "version": __version__,
         "author": "Agnes4m <Z735803792@163.com>",
@@ -61,23 +99,20 @@ __plugin_meta__ = PluginMetadata(
 
 """相当于启动就检查数据库"""
 
-
 @up.handle()
 async def _(matcher:Matcher,event: NoticeEvent):
     args = event.dict()
     if args['notice_type'] != 'offline_file':
         matcher.set_arg('txt',args)
         return
-    l4_file_path = l4_file[CHECK_FILE]
+    l4_file_path = l4_config.l4_ipall[l4_config.l4_number]['location']
     map_path = Path(l4_file_path, vpk_path)
     # 检查下载路径是否存在
     if not Path(l4_file_path).exists():
         await matcher.finish("你填写的路径不存在辣")
-        return
     if not Path(map_path).exists():
         await matcher.finish("这个路径并不是求生服务器的路径，请再看看罢")
-        return
-    url = args['file']['url']
+    url:str = args['file']['url']
     name: str = args['file']['name']
     # 如果不符合格式则忽略
     await up.send('已收到文件，开始下载')
@@ -89,27 +124,36 @@ async def _(matcher:Matcher,event: NoticeEvent):
     else:
         await matcher.finish("你可能上传了相同的文件，或者解压失败了捏")
 
-
-
-@up.got("is_sure", prompt="请选择上传位置（输入阿拉伯数字)")    
+path_list:str = '请选择上传位置（输入阿拉伯数字)'
+times = 0
+for one_path in l4_config.l4_ipall:
+    times += 1
+    path_msg = one_path['location']
+    path_list += f'\n {str(times)} | {path_msg}'
+    
+@up.got("is_sure", prompt=path_list)    
 async def _(matcher: Matcher):
     args = matcher.get_arg('txt')
+    l4_file = l4_config.l4_ipall
     if not args:
         await matcher.finish('获取文件出错辣，再试一次吧')
 
     is_sure = str(matcher.get_arg('is_sure')).strip()
     if not is_sure.isdigit():
         await matcher.finish('已取消上传')
-    file_number = len(l4_file)
-    is_sure = int(is_sure)
-    if is_sure > file_number or is_sure <= 0:
-        await matcher.finish('没有该序号')
-    l4_file_path = l4_file[is_sure - 1]
+    
+    file_path:str = ''
+    for one_server in l4_file:
+        if one_server['id_rank'] == is_sure:
+            file_path = one_server['location']
+    if not file_path:
+        await matcher.finish("没有这个序号拉baka")
 
-    map_path = Path(l4_file_path, vpk_path)
+
+    map_path = Path(file_path, vpk_path)
 
     # 检查下载路径是否存在
-    if not Path(l4_file_path).exists():
+    if not Path(file_path).exists():
         await matcher.finish("你填写的路径不存在辣")
     if not map_path.exists():
         await matcher.finish("这个路径并不是求生服务器的路径，请再看看罢")
@@ -138,8 +182,7 @@ async def _(matcher: Matcher):
 @find_vpk.handle()
 async def _(bot:Bot,event: MessageEvent,matcher: Matcher):
     name_vpk = []
-    map_path = Path(l4_file[CHECK_FILE],vpk_path)
-    print
+    map_path = Path(l4_config.l4_ipall[l4_config.l4_number]['location'],vpk_path)
     name_vpk = get_vpk(name_vpk,map_path)
     logger.info("获取文件列表成功")
     mes = "当前服务器下有以下vpk文件"
@@ -156,14 +199,14 @@ async def _(matcher:Matcher,args:Message = CommandArg()):
 
 @del_vpk.got("num",prompt="你要删除第几个序号的地图(阿拉伯数字)")
 async def _(matcher: Matcher,tag:int = ArgPlainText("num")):
-    map_path = Path(l4_file[CHECK_FILE],vpk_path)
+    map_path = Path(l4_config.l4_ipall[l4_config.l4_number]['location'],vpk_path)
     vpk_name = del_map(tag,map_path)
     await matcher.finish('已删除地图：' + vpk_name)
     
 @rename_vpk.handle()
 async def _(matcher:Matcher,matched: Tuple[int,str, str] = RegexGroup(),):
     num,useless,rename = matched
-    map_path = Path(l4_file[CHECK_FILE],vpk_path)
+    map_path = Path(l4_config.l4_ipall[l4_config.l4_number]['location'],vpk_path)
     logger.info('检查是否名字是.vpk后缀')
     if not rename.endswith('.vpk'):
         rename = rename + '.vpk'
@@ -216,59 +259,44 @@ async def _(matcher:Matcher,args:Message = CommandArg()):
 async def _(matcher:Matcher,tag:str = ArgPlainText("command")):
     tag = tag.strip()
     msg = await command_server(tag)
-    if l4_image:
+    try:
         await matcher.finish(mode_txt_to_img('服务器返回',msg))
-    else:
+    except:
         await matcher.finish(msg,reply_message = True)
         
 
-# 连续rcon连接
-# @connect_rcon.handle()
-# async def _(State:T_State,args:Message = CommandArg()):
-#     msg = args.extract_plain_text()
-    # client = RCONClient(l4_host[CHECK_FILE], l4_port[CHECK_FILE], l4_rcon[CHECK_FILE])
-    # await client.connect()
-    # State['client'] = client
-#     if msg:
-#         connect_rcon.set_arg(key="prompt",message=args)
-        
-# @connect_rcon.got("prompt", prompt="连接开始...如果需要停止则输入“结束连接”")
-# async def handle_chat(State:T_State,event: MessageEvent, prompt: Message = Arg(), msg: str = ArgPlainText("prompt")):
-    # session_id = event.get_session_id()
-    # client:RCONClient = State['client']
-
-    # await client.close()
-    # await connect_rcon.finish('聊天结束...')
-        
         
 @check_path.handle()
 async def _(matcher:Matcher,args:Message = CommandArg()):
-    global CHECK_FILE
     msg = args.extract_plain_text()
     if msg.startswith('切换'):
         msg_number = int(''.join(msg.replace('切换', ' ').split()))
-        if msg_number > len(l4_file) or msg_number < 0:
+        if msg_number > len(l4_config.l4_ipall) or msg_number < 0:
             await matcher.send('没有这个序号的路径呐')
         else:
-            CHECK_FILE = msg_number - 1
-            now_path = l4_file[CHECK_FILE]
-            await matcher.send(f'已经切换路径为\n{str(CHECK_FILE+1)}、{now_path}')
+            l4_config.l4_number = msg_number - 1
+            now_path = l4_config.l4_ipall[l4_config.l4_number]['location']
+            await matcher.send(f'已经切换路径为\n{str(l4_config.l4_number+1)}、{now_path}')
+            config_manager.save()
     else: 
-        now_path = l4_file[CHECK_FILE]
-        await matcher.send(f'当前的路径为\n{str(CHECK_FILE+1)}、{now_path}')
+        now_path = l4_config.l4_ipall[l4_config.l4_number]['location']
+        await matcher.send(f'当前的路径为\n{str(l4_config.l4_number+1)}、{now_path}')
         
         
-@queries.handle()
-async def _(matcher:Matcher,args:Message = CommandArg()):
-    msg = args.extract_plain_text()
-    if msg:
-        matcher.set_arg("ip",args)
-
-@queries.got("ip",prompt="请输入ip,格式如中括号内【127.0.0.1】【114.51.49.19:1810】")
-async def _(matcher:Matcher,tag:str = ArgPlainText("ip")):
-    ip = split_maohao(tag)
-    msg = await queries_server(ip)
-    await matcher.finish(msg)
+@queries_comm.handle()
+async def _(matcher:Matcher,event:MessageEvent,keyword:str = Keyword()):
+    msg = event.get_plaintext()
+    if not msg:
+        await matcher.finish('ip格式如中括号内【127.0.0.1】【114.51.49.19:1810】')
+    ip = msg.split(keyword)[-1].split('\r')[0].split('\n')[0].split(' ')
+    for one_msg in ip:
+        if one_msg and one_msg[-1].isdigit():
+            break
+    if not one_msg:
+        await matcher.finish()
+    ip_list = split_maohao(one_msg)
+    msg = await queries_server(ip_list)
+    await str_to_picstr(msg,matcher)
     
 
 @add_queries.handle()
@@ -364,17 +392,17 @@ async def _(matcher: Matcher,bot:Bot,event:GroupMessageEvent,state:T_State):
     
 
 
-@updata.handle()
-async def _(matcher:Matcher,args:Message = CommandArg()):
-    """更新"""
-    msg = args.extract_plain_text()
-    if not msg:
-        load_josn()
-        reload_ip()
-        await matcher.finish('已更新缓存数据')
-    else:
-        message = await write_json(msg)
-        await matcher.finish(message)
+# @updata.handle()
+# async def _(matcher:Matcher,args:Message = CommandArg()):
+#     """更新"""
+#     msg = args.extract_plain_text()
+#     if not msg:
+#         load_josn()
+#         reload_ip()
+#         await matcher.finish('已更新缓存数据')
+#     else:
+#         message = await write_json(msg)
+#         await matcher.finish(message)
   
 
             
@@ -406,7 +434,7 @@ async def _(bot:Bot,event:MessageEvent,state:T_State,tag = Arg("image")):
 
 @smx_file.handle()
 async def _(matcher:Matcher,):
-    smx_path = Path(l4_file[CHECK_FILE],"left4dead2/addons/sourcemod/plugins")
+    smx_path = Path(l4_config.l4_ipall[l4_config.l4_number]['location'],"left4dead2/addons/sourcemod/plugins")
     smx_list = []
     name_smx = get_vpk(smx_list,smx_path,file_=".smx")
     logger.info("获取文件列表成功")
@@ -415,18 +443,18 @@ async def _(matcher:Matcher,):
     msg = mes_list(msg,name_smx).replace(" ","")
     await matcher.finish(mode_txt_to_img(mes,msg))
     
-@search_api.handle()
-async def _(matcher:Matcher,state:T_State,event:GroupMessageEvent,args:Message = CommandArg()):
-    msg:str = args.extract_plain_text()
-    # if msg.startswith('代码'):
-        # 建图代码返回三方图信息
-    data = await seach_map(msg,l4_qq,l4_key)
-    # else:
-    if type(data) == str:
-        await matcher.finish(data)
-    else:
-        state['maps'] = data
-        await matcher.send(await map_dict_to_str(data))
+# @search_api.handle()
+# async def _(matcher:Matcher,state:T_State,event:GroupMessageEvent,args:Message = CommandArg()):
+#     msg:str = args.extract_plain_text()
+#     # if msg.startswith('代码'):
+#         # 建图代码返回三方图信息
+#     data = await seach_map(msg,l4_config.l4_master[0],l4_config.l4_key)
+#     # else:
+#     if type(data) == str:
+#         await matcher.finish(data)
+#     else:
+#         state['maps'] = data
+#         await matcher.send(await map_dict_to_str(data))
         
 @search_api.got("is_sure",prompt='如果需要上传，请发送 "yes"')    
 async def _(matcher:Matcher,bot:Bot,event:GroupMessageEvent,state:T_State):
@@ -435,7 +463,7 @@ async def _(matcher:Matcher,bot:Bot,event:GroupMessageEvent,state:T_State):
         data_dict:dict = state['maps'][0]
         if type(data_dict) == dict:
             logger.info('开始上传')
-            if l4_only:
+            if l4_config.l4_only:
                 data_file,file_name = await url_to_byte_name(data_dict['url'],'htp')
             else:
                 data_file,file_name = await url_to_byte_name(data_dict['url'])
@@ -453,6 +481,16 @@ async def _(matcher:Matcher,bot:Bot,event:GroupMessageEvent,state:T_State):
     else:
         await matcher.finish('已取消上传')
         
+# @reload_ip.handle()
+# async def _(matcher:Matcher):
+#     global matchers
+#     await matcher.send('正在重载ip，可能需要一点时间')
+#     for _, l4_matchers in matchers.items():
+#         for l4_matcher in l4_matchers:
+#             l4_matcher.destroy()
+#     await get_des_ip()
+#     await matcher.finish('已重载ip')
+    
 
 @driver.on_shutdown
 async def close_db():
