@@ -1,4 +1,4 @@
-from ..config import (
+from ..l4d2_utils.config import (
     DATASQLITE,
     table_data,
     L4d2_players_tag,
@@ -14,7 +14,6 @@ from nonebot.log import logger
 
 
 
-
 class L4D2DataSqlite:
     """连接数据库和断开数据库，以及一些检查函数"""
     def __init__(self):
