@@ -1,15 +1,18 @@
 
 from bs4 import BeautifulSoup
+import jinja2
 from nonebot.log import logger
 from nonebot_plugin_htmlrender import html_to_pic
 from typing import List,Optional
+
+
 # from .htmlimg import dict_to_dict_img
 # from ..l4d2_anne.anne_telecom import ANNE_API
-from ..config import TEXT_PATH
+from ..l4d2_utils.config import TEXT_PATH
 from .download import get_head_by_user_id_and_save
 from .send_image_tool import convert_img
-import jinja2
-from ..config import l4_style
+
+from ..l4d2_utils.config import l4_config
 template_path = TEXT_PATH/"template"
 
 env = jinja2.Environment(
@@ -31,7 +34,6 @@ async def out_png(usr_id,data_dict:dict):
                 wait=0,
                 viewport={"width": 1100, "height": 800},
                 template_path=f"file://{template_path.absolute()}",)
-    print(type(pic))
     return pic
 
 
@@ -81,13 +83,16 @@ async def server_ip_pic(msg_list:List[dict]):
                 players_list.append("")
             server_info['Players'] = players_list
     pic = await get_help_img(msg_list)
-
+    if pic:
+        logger.success('正在输出图片')
+    else:
+        logger.warning('我的图图呢')
     return pic
 
 
 async def get_help_img(plugins: List[dict]) -> Optional[bytes]:
     try:
-        if l4_style == 'black':
+        if l4_config.l4_style == 'black':
             template = env.get_template("help_dack.html")
         else:
             template = env.get_template("help.html")
