@@ -4,8 +4,8 @@ from typing import List
 async def queries(ip:str,port:int):
     port = int(port)
     msg_dict = await queries_dict(ip,port)
-    message = 'ip:' + msg_dict['ip'] + '\n'
-    message += '名称：' + msg_dict['name'] + '\n'
+    print(msg_dict['name'],type(msg_dict['name']))
+    message = f"名称：{msg_dict['name']}\n"
     message += f"地图：{msg_dict['map_']}\n"
     message += f"延迟：{msg_dict['ping']}\n"
     message += f"玩家：{msg_dict['players']} / {msg_dict['max_players']}\n"
@@ -17,7 +17,6 @@ async def queries_dict(ip:str,port:int) -> dict:
     msg_dict = {}
     # message_dict = await l4d(ip,port)
     msg:a2s.SourceInfo = await a2s.ainfo((ip,port))
-    # message_dict = await l4d2.server(ip,port,times=5)
     msg_dict['folder'] =  msg.folder
     msg_dict['name'] =  msg.server_name
     msg_dict['map_'] =  msg.map_name
@@ -26,6 +25,7 @@ async def queries_dict(ip:str,port:int) -> dict:
     msg_dict['rank_players'] =  f'{msg.player_count}/{msg.max_players}'
     msg_dict['ip'] = str(ip) + ':' +str(port)
     msg_dict['ping'] = f"{msg.ping*1000:.0f}ms"
+    msg_dict['system'] =  f"{msg.platform}.svg"
     if msg_dict['players'] < msg_dict['max_players']:
         msg_dict['enabled'] = True
     else:
@@ -99,4 +99,15 @@ async def convert_duration(duration: int) -> str:
     time_str += f"{int(seconds)}s"
     return time_str.strip()
 
+async def server_rule_dict(ip:str,port:int): 
+    port = int(port)
+    ip = str(ip)
+    msg_dict = {}
+    # message_dict = await l4d(ip,port)
+    try:
+        msg:dict = await a2s.arules((ip,port))
+        msg_dict['tick'] = msg['l4d2_tickrate_enabler'] + "tick"
+    except:
+        msg_dict['tick'] = ''
+    return msg_dict
 
