@@ -9,11 +9,9 @@ from nonebot import get_bot, get_app
 
 from pathlib import Path
 
-
 from nonebot import get_driver, logger
-from .config import *
-from ..config import *
-from ..utils import split_maohao
+from ..l4d2_utils.config import *
+from ..l4d2_utils.utils import split_maohao
 from ..l4d2_queries.qqgroup import qq_ip_querie
 CONFIG_PATH = Path() / 'data' / 'L4D2' / 'l4d2.yml'
 
@@ -105,8 +103,17 @@ async def init_web():
                 'msg':    '获取群和好友列表失败，请确认已连接GOCQ'
             }
 
-    @app.get('/l4d2/api/chat_global_config', response_class=JSONResponse, dependencies=[authentication()])
-    async def get_chat_global_config():
+    @app.post('/l4d2/api/l4d2_global_config', response_class=JSONResponse, dependencies=[authentication()])
+    async def post_l4d2_global_config(data: dict):
+        config_manager.config.update(**data)
+        config_manager.save()
+        return {
+            'status': 0,
+            'msg':    '保存成功'
+        }
+
+    @app.get('/l4d2/api/l4d2_global_config', response_class=JSONResponse, dependencies=[authentication()])
+    async def get_l4d2_global_config():
         try:
             bot = get_bot()
             groups = await bot.get_group_list()
@@ -120,6 +127,8 @@ async def init_web():
                      member in members])
             config = config_manager.config.dict(exclude={'group_config'})
             config['member_list'] = member_list
+            config['l4_styles'] = ['standard','black']
+
             return config
         except ValueError:
             return {
@@ -127,10 +136,10 @@ async def init_web():
                 'msg':    '获取群和好友列表失败，请确认已连接GOCQ'
             }
             
-    @app.get('/l4d2/api/get_chat_contexts', response_class=JSONResponse, dependencies=[authentication()])
-    async def get_chat_context():
+    @app.get('/l4d2/api/get_query_contexts', response_class=JSONResponse, dependencies=[authentication()])
+    async def get_query_context():
         try:
-            from ..command import ALL_HOST
+            from ..l4d2_utils.command import ALL_HOST
             this_ips = ALL_HOST
             ip_lists = []
             for ip_list, v in this_ips.items():
@@ -138,6 +147,11 @@ async def init_web():
                     host, port = split_maohao(d['ip'])
                     ip_lists.append((d['id'], ip_list, host, port))
             data_dict = await qq_ip_querie(ip_lists)
+            if not data_dict:
+                return{
+                'status': -100,
+                'msg':    '返回失败，请确保有可用的服务器ip' 
+                }
             data_list = data_dict['msg_list']
             return {
                 'status': 0,
@@ -153,7 +167,55 @@ async def init_web():
                 'msg':    '返回失败，请确保网络连接正常'
             }
 
+    @app.get('/l4d2/api/get_l4d2_messages', response_class=JSONResponse, dependencies=[authentication()])
+    async def get_l4d2_messages():
+        try:
+            l4_ipall = config_manager.config.l4_ipall
+            config = [{'label': item['server_id'] , 'value': item['id_rank']}
+                for item in l4_ipall]
+            return {
+                'status': 0,
+                'msg': 'ok',
+                'data': {'server_list':config}
+            }
+        except ValueError:
+            return {
+                'status': -100,
+                'msg':    '返回失败，请确保网络连接正常'
+            }
+    @app.get('/l4d2/api/l4d2_server_config', response_class=JSONResponse, dependencies=[authentication()])
+    async def get_l4d2_server_config(id_rank :str):
+        try:
+            l4_ipall = config_manager.config.l4_ipall
+            config = {}
+            for item in l4_ipall:
+                if item['id_rank'] == id_rank :
+                    item['place'] = item['place'] == 'True' or item['place'] == True
+                    config = item
+                    break
+            return {
+                'status': 0,
+                'msg': 'ok',
+                'data': config
+            }
+        except ValueError:
+            return {
+                'status': -100,
+                'msg':    '返回失败，请确保网络连接正常'
+            }
+        
+    @app.post('/l4d2/api/l4d2_server_config', response_class=JSONResponse, dependencies=[authentication()])
+    async def post_l4d2_server_config(id_rank :str,data: dict):
+        for one in config_manager.config.l4_ipall:
+            if one['id_rank']==id_rank:
+                one.update(**data)
+        config_manager.save()
+        return {
+            'status': 0,
+            'msg':    '保存成功'
+        }        
 
+        
     @app.get('/l4d2', response_class=RedirectResponse)
     async def redirect_page():
         return RedirectResponse('/l4d2/login')
@@ -165,7 +227,7 @@ async def init_web():
 
     @app.get('/l4d2/admin', response_class=HTMLResponse)
     async def admin_page_app():
-        return admin_app.render(site_title='l4d2-Chat 后台管理',
+        return admin_app.render(site_title='l4d2-l4d2 后台管理',
                                 theme='ang',
                                 requestAdaptor=requestAdaptor,
                                 responseAdaptor=responseAdaptor)
